@@ -1,7 +1,6 @@
 from immutabledict import immutabledict
 import strax
 import straxen
-import numpy as np
 
 
 common_opts = dict(
@@ -46,6 +45,8 @@ xnt_common_config = dict(
         nveto_blank=(2999, 2999)),
     # Clustering/classification parameters
     s1_max_rise_time=100,
+    s2_xy_correction_map=("CMT_model", ('s2_xy_map', "ONLINE"), True),
+    elife_file=("elife_model", "ONLINE",True),
 )
 
 # Plugins in these files have nT plugins, E.g. in pulse&peak(let)
@@ -119,7 +120,8 @@ def xenonnt_online(output_folder='./strax_data',
         st.storage += [straxen.OnlineMonitor(
             readonly=not we_are_the_daq,
             take_only=('veto_intervals',
-                       'online_monitor',))]
+                       'online_peak_monitor',
+                       'event_basics',))]
 
     # Remap the data if it is before channel swap (because of wrongly cabled
     # signal cable connectors) These are runs older than run 8797. Runs
@@ -143,10 +145,10 @@ def xenonnt_led(**kwargs):
     return st
 
 
-# This gain model is a temporary solution until we have a nice stable one
+# This gain model is the average to_pe. For something more fancy use the CMT
 def xenonnt_simulation(output_folder='./strax_data'):
     import wfsim
-    xnt_common_config['gain_model'] = ('to_pe_per_run', 'to_pe_nt.npy')
+    xnt_common_config['gain_model'] = ('to_pe_constant', 0.01)
     st = strax.Context(
         storage=strax.DataDirectory(output_folder),
         config=dict(detector='XENONnT',
@@ -237,7 +239,11 @@ x1t_common_config = dict(
     peak_split_gof_threshold=(
         None,  # Reserved
         ((0.5, 1), (3.5, 0.25)),
-        ((2, 1), (4.5, 0.4))))
+        ((2, 1), (4.5, 0.4))),
+    left_event_extension=int(1e6),
+    right_event_extension=int(1e6),
+)
+
 
 
 def demo():
